==> react-atom-panel-1.17.0.tgz: package/lib/ImagePanel.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "id", "children"];
import cx from 'classnames';
import PropTypes from 'prop-types';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { ALPHA, BORDER_RADIUS, DEFAULT_ALPHA, ELEVATION, HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";
var getClassNames = function getClassNames(_ref) {
  var verticalAlign = _ref.verticalAlign,
    horizontalAlign = _ref.horizontalAlign,
    resized = _ref.resized,
    overlayColor = _ref.overlayColor,
    _ref$overlayAlpha = _ref.overlayAlpha,
    overlayAlpha = _ref$overlayAlpha === void 0 ? ALPHA[DEFAULT_ALPHA] : _ref$overlayAlpha,
    color = _ref.color,
    rounded = _ref.rounded,
    elevation = _ref.elevation;
  var BASE_CLASS = 'sui-atom-panel';
  var IMAGE_PANEL_CLASS = BASE_CLASS + "-image";
  return cx(BASE_CLASS, rounded !== BORDER_RADIUS.NONE && BASE_CLASS + "--rounded-" + rounded, IMAGE_PANEL_CLASS + "--vertical-" + verticalAlign, IMAGE_PANEL_CLASS + "--horizontal-" + horizontalAlign, overlayColor && BASE_CLASS + "--" + overlayColor + "-overlay-" + overlayAlpha, BASE_CLASS + "-color--" + color, resized && IMAGE_PANEL_CLASS + "--resized", elevation !== ELEVATION.NONE && BASE_CLASS + "--elevation-" + elevation);
};
var getStyles = function getStyles(_ref2) {
  var src = _ref2.src;
  var url = "url(" + src + ")";
  return {
    backgroundImage: url
  };
};
var ImagePanel = function ImagePanel(_ref3) {
  var _ref3$as = _ref3.as,
    as = _ref3$as === void 0 ? 'div' : _ref3$as,
    id = _ref3.id,
    children = _ref3.children,
    props = _objectWithoutPropertiesLoose(_ref3, _excluded);
  return /*#__PURE__*/_jsx(PolymorphicElement, {
    as: as,
    id: id,
    className: getClassNames(props),
    style: getStyles(props),
    children: children
  });
};
ImagePanel.displayName = 'ImagePanel';
export default ImagePanel;
export { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS };

==> react-atom-panel-1.18.0.tgz: package/lib/ImagePanel.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "id", "children"];
import cx from 'classnames';
import PropTypes from 'prop-types';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { ALPHA, BORDER_RADIUS, DEFAULT_ALPHA, ELEVATION, HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";
var getClassNames = function getClassNames(_ref) {
  var verticalAlign = _ref.verticalAlign,
    horizontalAlign = _ref.horizontalAlign,
    resized = _ref.resized,
    overlayColor = _ref.overlayColor,
    _ref$overlayAlpha = _ref.overlayAlpha,
    overlayAlpha = _ref$overlayAlpha === void 0 ? ALPHA[DEFAULT_ALPHA] : _ref$overlayAlpha,
    color = _ref.color,
    rounded = _ref.rounded,
    elevation = _ref.elevation,
    isFullWidth = _ref.isFullWidth,
    isFullHeight = _ref.isFullHeight;
  var BASE_CLASS = 'sui-atom-panel';
  var IMAGE_PANEL_CLASS = BASE_CLASS + "-image";
  return cx(BASE_CLASS, rounded !== BORDER_RADIUS.NONE && BASE_CLASS + "--rounded-" + rounded, IMAGE_PANEL_CLASS + "--vertical-" + verticalAlign, IMAGE_PANEL_CLASS + "--horizontal-" + horizontalAlign, overlayColor && BASE_CLASS + "--" + overlayColor + "-overlay-" + overlayAlpha, BASE_CLASS + "-color--" + color, resized && IMAGE_PANEL_CLASS + "--resized", isFullWidth && BASE_CLASS + "--fullWidth", isFullHeight && BASE_CLASS + "--fullHeight", elevation !== ELEVATION.NONE && BASE_CLASS + "--elevation-" + elevation);
};
var getStyles = function getStyles(_ref2) {
  var src = _ref2.src;
  var url = "url(" + src + ")";
  return {
    backgroundImage: url
  };
};
var ImagePanel = function ImagePanel(_ref3) {
  var _ref3$as = _ref3.as,
    as = _ref3$as === void 0 ? 'div' : _ref3$as,
    id = _ref3.id,
    children = _ref3.children,
    props = _objectWithoutPropertiesLoose(_ref3, _excluded);
  return /*#__PURE__*/_jsx(PolymorphicElement, {
    as: as,
    id: id,
    className: getClassNames(props),
    style: getStyles(props),
    children: children
  });
};
ImagePanel.displayName = 'ImagePanel';
export default ImagePanel;
export { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS };
